#
# spec file for package libdnf
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023 Neal Gompa <ngompa@opensuse.org>.
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libsolv_version 0.7.21
%global libmodulemd_version 2.13.0
%global librepo_version 1.18.0
%global dnf_conflict 4.11.0
%global swig_version 3.0.12

# Keep tests switched off for now, it bombs out on SUSE
%bcond_with check

# Keep valgrind tests switched off for now
%bcond_with valgrind

%define somajor 2
%define libname %{name}%{somajor}
%define devname %{name}-devel

Name:           libdnf
Version:        0.73.4
Release:        1.1
Summary:        Library providing C and Python APIs atop libsolv
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/rpm-software-management/%{name}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# Backports from upstream

# Fixes proposed upstream

# openSUSE specific fixes
## Fix libdnf build with static libsolvext
Patch1000:      libdnf-0.72.0-with-static-libsolvext.patch
## Switch default reposdir to /etc/dnf/repos.d
Patch1001:      libdnf-0.54.2-Switch-default-reposdir-to-etc-dnf-repos.d.patch
## Switch allow_vendor_change off by default
Patch1002:      libdnf-0.55.0-Switch-allow_vendor_change-off.patch
## Migrate DNF persistent state directory to /usr/lib/sysimage
Patch1003:      libdnf-0.58.0-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch

BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gpgme-devel
BuildRequires:  libsolv-devel >= %{libsolv_version}
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
%if %{with valgrind}
BuildRequires:  valgrind
%endif
BuildRequires:  rpm-devel >= 4.15.0
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.46.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
BuildRequires:  pkgconfig(smartcols)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zck) >= 0.9.11

# libsolv specific BRs
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

%description
This library provides a high level RPM package manager that can be integrated
into applications to manage software. It is currently used by DNF, RPM-OSTree,
and PackageKit.

%package -n %{libname}
Summary:        Library providing an interface atop libsolv
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}-%{release}
# gobject-introspection is no longer used
Obsoletes:      typelib-1_0-Dnf-1_0 < 0.24.1
# To avoid API issues with librepo and incomprehensible crashes
Requires:       librepo0%{?_isa} >= %{librepo_version}
# To avoid API issues with libmodulemd
Requires:       libmodulemd2%{?_isa} >= %{libmodulemd_version}

%description -n %{libname}
This library provides an interface atop libsolv, and a high-level
RPM package manager library interface.

%package -n python3-%{name}
Summary:        Python 3 bindings for the libdnf library
Group:          Development/Libraries/Python
Requires:       %{libname}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  swig >= %{swig_version}
Conflicts:      python3-dnf < %{dnf_conflict}

%description -n python3-%{name}
This package provides the Python 3 bindings for the libdnf library.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package provides the headers and libraries for developing applications
that use %{name}.

%package -n hawkey-man
Summary:        Documentation for the hawkey Python bindings
Group:          Documentation/Man
BuildRequires:  python3-Sphinx
BuildArch:      noarch

%description -n hawkey-man
This package provides the man pages for the hawkey Python bindings.

%package -n python3-hawkey
Summary:        Python 3 bindings for the hawkey interface
Group:          Development/Libraries/Python
BuildRequires:  python3-devel
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       python3-%{name}%{?_isa} = %{version}-%{release}
Recommends:     hawkey-man = %{version}-%{release}
Conflicts:      python3-dnf < %{dnf_conflict}
# Python 2 subpackage has been dropped
Obsoletes:      python2-hawkey < 0.24.1

%description -n python3-hawkey
This package provides the Python 3 bindings for %{name} through
the hawkey interface.

%package repo-config-zypp
Summary:        Enables Zypper repository configuration for DNF
Group:          System/Packages
# We're compatible with any SUSE Linux distribution
Requires:       (product(SUSE_SLE) or suse-release)
# Only one instance of this package may be installed at a time...
Provides:       rpm-repos-openSUSE
Conflicts:      rpm-repos-openSUSE
BuildArch:      noarch

%description repo-config-zypp
This package allows libdnf and all consumers to be able to reuse
repository configuration files set for Zypper.


%lang_package

%prep
%autosetup -p1

# Fix sphinx-build run...
sed -e "s/sphinx-build-3/sphinx-build-%{python3_version}/" -i docs/hawkey/CMakeLists.txt

%build
%cmake -DPYTHON_DESIRED:FILEPATH=%{__python3} %{!?with_valgrind:-DDISABLE_VALGRIND=1}
%cmake_build

%if %{with check}
%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}

if [ "$(id -u)" = "0" ] ; then
        cat <<ERROR 1>&2
Package tests cannot be run under superuser account.
Please build the package as non-root user.
ERROR
        exit 1
fi
pushd build
  make ARGS="-V" test
popd

%endif

%install
%cmake_install

%find_lang %{name}

# For repo-config-zypp subpackage
mkdir -p %{buildroot}%{_sysconfdir}/zypp/repos.d
ln -sr %{buildroot}%{_sysconfdir}/zypp/repos.d %{buildroot}%{_sysconfdir}/distro.repos.d

%python_compileall
%fdupes %{buildroot}%{python3_sitearch}

%ldconfig_scriptlets -n %{libname}

%files -n %{libname} -f %{name}.lang
%license COPYING
%doc README.md AUTHORS
%{_libdir}/%{name}.so.%{somajor}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/README

%files -n python3-%{name}
%license COPYING
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}-%{version}.dist-info/

%files -n %{devname}
%license COPYING
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%{_datadir}/gtk-doc/html/%{name}/

%files -n hawkey-man
%license COPYING
%{_mandir}/man3/hawkey.3*

%files -n python3-hawkey
%license COPYING
%{python3_sitearch}/hawkey/

%files repo-config-zypp
%license COPYING
# Co-own the zypp repos dir
%dir %{_sysconfdir}/zypp
%dir %{_sysconfdir}/zypp/repos.d
%{_sysconfdir}/distro.repos.d

%changelog
* Sat Feb  8 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.73.4:
  * Set POOL_FLAG_ADDFILEPROVIDESFILTERED only when not loading
    filelists
- make libdnf-repo-config-zypp noarch
* Wed Sep  4 2024 pgajdos@suse.com
- version update to 0.73.3
  * Support colon in username, use LRO_USERNAME and LRO_PASSWORD
  * Set pool flag to fix pool_addfileprovides_queue() without filelists.xml
  * Fix a memory leak in glob_for_cachedir()
* Tue Jul 30 2024 pgajdos@suse.com
- version update to 0.73.2
  * context: use rpmtsAddReinstallElement() when doing a reinstall by @kontura in #1650
  * MergedTransaction: Fix invalid memory access when dropping items by @jan-kolarik in #1658
  * ConfigParser: fix use-out-of-scope leaks by @evan-goode in #1661
  * Since we use rpmtsAddReinstallElement rpm also uninstalls the package by @kontura in #1660
  * Fix countme bucket calculation by @dmnks in #1662
* Wed Apr  3 2024 pgajdos@suse.com
- version update to 0.73.1
  * Bug fixes:
  - Fix https://issues.redhat.com/browse/RHEL-27657
  - subject-py: Fix memory leak
  * Others:
  - MergedTransaction: Calculate RPM difference between two same versions as no-op
  - Onboard packit tests
  - Add virtual destructor to TransactionItem
* Thu Feb 15 2024 pgajdos@suse.com
- version update to 0.73.0
  * Major changes:
  * filelists metadata not loaded by default
  * deltarpm disabled by default
  * New features:
  * conf: Introduce new optional_metadata_types option to load
    filelists on demand
  * goal: Method for detecting file dependency problems
* Sat Nov  4 2023 Neal Gompa <ngompa@opensuse.org>
- Update to 0.72.0
  + PGP: Use new librepo PGP API, remove gpgme dependency
  + API: Basic support for OpenPGP public keys
  + Avoid using GNU extensions in the dependency splitter regex
  + filterAdvisory: match installed_solvables sort with lower_bound (rh#2212838)
  + Make code C++20 compatible
  + Avoid reinstalling installonly packages marked for ERASE (rh#2163474)
  + transaction: Save the reason for installing (rh#1733274)
  + hawkey.subject: get_best_selectors only obsoleters of latest (rh#2183279, rh#2176263)
  + conf: Add limited shell-style variable expansion (rh#1789346)
  + conf: Add support for $releasever_major, $releasever_minor (rh#1789346)
  + repo: Don't download the repository if the local cache is up to date
  + Allow DNF to be removed by DNF 5 (rh#2221907)
  + Include dist-info for python3-libdnf
  + bindings: Load all modules with RTLD_GLOBAL
  + Update translations
- Fix RHBZ references
- Refresh patch to link with static libsolvext
  + Remove patch: libdnf-0.48.0-with-static-libsolvext.patch
  + Add patch: libdnf-0.72.0-with-static-libsolvext.patch
* Tue Aug  1 2023 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Update to 0.70.2:
  * Support "proxy=none" in main config (rh#2155713)
  * Fix #1558: Don't assume inclusion of cstdint
  * Disconnect monitors in dnf_repo_loader_finalize() (rh#2070153)
* Tue May 30 2023 Dirk Müller <dmueller@suse.com>
- update to 0.70.1:
  * Add repoid to solver errors for RPMs (rh#2179413)
  * Avoid using obsolete RPM API and drop redundant calls
  * Remove DNF from list of protected packages
- avoid bashism
* Mon Feb 27 2023 Andreas Stieger <andreas.stieger@gmx.de>
- libdnf 0.70.0:
  * Allow change of architecture for packages during security
    updates with noarch involved
  * "dnf_keyring_add_public_keys": reset localError to NULL after
    free
  * context: Get RPM db path from RPM
  * Fix memory leak of SolvUserdata
* Fri Feb 24 2023 Bruno Pitrus <brunopitrus@hotmail.com>
- Precompile python bytecode (boo#1208151)
* Sat Oct 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- libdnf 0.69.0:
  * Expose librepo max_downloads_per_mirror configuration
- includes changes from 0.68.0:
  * context: Support (NEVRA forms, provides, file provides)
    including globs in the dnf_context_remove func
  * dnf-context: Disconnect signal handler before dropping file
    monitor ref
  * Filter out advisory pkgs with different arch during advisory
    upgrade, fixes possible problems in dependency resulution
  * Gracefully handle failure to open repo primary file
  * Fix listing a repository without cpeid
* Wed May  4 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.67.0:
  * Add 'loongarch' support
  * Use dnf solv userdata to check versions and checksum (rh#2027445)
  * context: Substitute all repository config options (rh#2076853)
* Sun Mar 27 2022 Neal Gompa <ngompa13@gmail.com>
- Update to 0.66.0
  + Use `rpmdbCookie` from librpm, remove `hawkey.Sack._rpmdb_version`
  + Fix handling transaction id in resolveTransactionItemReason (rh#2010259, rh#2053014)
  + Remove deprecated assertions (rh#2027383)
  + Increase required rpm version since we use `rpmdbCookie()`
  + Skip rich deps for autodetection of unmet dependencies (rh#2033130)
- Use ldconfig_scriptlets macro for ldconfig scriptlets
* Wed Nov  3 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 0.65.0
  + Add support for excluding packages to be installed as weak dependencies
  + Add support for autodetecting packages to be excluded from being installed as weak dependencies
  + Turn off strict validation of modulemd documents (rh#2004853, rh#2007166, rh#2007167)
  + Implement logic for demodularization of modular rpms (rh#1805260)
  + DnfContext: fix handling of default module profiles
  + ModuleMetadata: gracefully handle modules with no defaults
  + Remove failovermethod config option (rh#1961083)
* Fri Aug 27 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 0.63.1
  + ModuleProfile: add isDefault()
  + ModulePackage: add getDefaultProfile()
  + Add new dnf_context_module_install() C API
  + Fix a crash when [media] section in .treeinfo is missing for bootable media (rh#1946024)
  + Add hy_query_get_advisory_pkgs to C API (rh#1960561)
  + Add dnf_advisorypkg_get_advisory()
  + DNF does not fail on non UTF-8 file names in a package (rh#1893176)
  + Improve error-reporting for modular functions
- Drop patch included in this release
  + Patch: 0001-Fix-a-crash-when-repoId-not-found-in-loaded-conf-gke.patch
* Thu Apr 15 2021 Neal Gompa <ngompa13@gmail.com>
- Add patch to fix crash when loading DVD repositories
  + Patch: 0001-Fix-a-crash-when-repoId-not-found-in-loaded-conf-gke.patch
* Tue Apr 13 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 0.62.0
  + Change order of TransactionItemReason (rh#1921063)
  + Add two new comperators for security filters (rh#1918475)
  + Apply security filters for candidates with lower priority
  + Fix: Goal - translation of messages in global maps
  + Enhance description of modular solvables
  + Improve performance for module query
  + Change mechanism of modular errata applicability (rh#1804234)
  + dnf_transaction_commit(): Remove second call to rpmtsSetVSFlags
  + Fix a couple of memory leaks
  + Fix: Setting of librepo handle in newHandle function
  + Remove failsafe data when module is not enabled (rh#1847035)
  + Expose librepo's checksum functions via SWIG
  + Fix: Mising check of "hy_split_nevra()" return code
  + Do not allow 1 as installonly_limit value (rh#1926261)
  + Fix check whether the subkey can be used for signing
  + Hardening: add signature check with rpmcliVerifySignatures
    (CVE-2021-3445, CVE-2021-3421, CVE-2021-20271, rh#1932079, rh#1932089, rh#1932090, boo#1183779)
  + Add a config option sslverifystatus, defaults to false (rh#1814383)
  + [context] Add API for distro-sync
* Tue Mar  2 2021 Neal Gompa <ngompa13@gmail.com>
- Fix dependency for repo-config-zypp subpackage to work with SLE
* Tue Mar  2 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 0.60.0
  + Fix repo.fresh() implementation
  + Fix: Fully set ssl in newHandle function
  + [conf] Add options for working with certificates used with proxy
  + Apply proxy certificate options
  + lock: Switch return-if-fail to assert to quiet gcc -fanalyzer
  + build-sys: Clean up message about Python bindings
  + Modify module NSVCA parsing - context definition (rh#1926771)
  + [context] Fix: dnf_package_is_installonly (rh#1928056)
  + Fix problematic language
  + Add getApplicablePackages to advisory and isApplicable to advisorymodule
  + Keep isAdvisoryApplicable to preserve API
  + Run ModulePackageContainerTest tests in tmpdir, merge interdependent
  + [context] Support config file option "proxy_auth_method", defaults "any"
  + Properly handle multiple collections in updateinfo.xml (rh#1804234)
  + Support main config file option "installonlypkgs"
  + Support main config file option "protected_packages"
- Drop patches now part of this release
  + Patch: 0001-context-Support-config-file-option-installonlypkgs.patch
  + Patch: 0002-context-Support-config-file-option-protected_package.patch
  + Patch: 0001-context-Fix-dnf_package_is_installonly-RhBug-1928056.patch
  + Patch: 0001-Fix-librepo-version-required-in-CMakeList.txt-1.12.0.patch
  + Patch: 0002-Fix-Fully-set-ssl-in-newHandle-function.patch
  + Patch: 0003-conf-Add-options-for-working-with-certificates-used-.patch
  + Patch: 0004-Apply-proxy-certificate-options.patch
  + Patch: 0001-Deduplicate-code-create-Repo-Impl-stringToProxyAuthM.patch
  + Patch: 0002-context-Support-config-file-option-proxy_auth_method.patch
* Fri Feb 26 2021 Neal Gompa <ngompa13@gmail.com>
- Backport more fixes for using certs for repo authorization
  + Patch: 0001-Deduplicate-code-create-Repo-Impl-stringToProxyAuthM.patch
  + Patch: 0002-context-Support-config-file-option-proxy_auth_method.patch
* Thu Feb 25 2021 Neal Gompa <ngompa13@gmail.com>
- Add repo-config-zypp subpackage to allow easily using Zypper
  repository configuration
* Tue Feb 23 2021 Neal Gompa <ngompa13@gmail.com>
- Backport support for using certificates for repository authorization
  + Patch: 0001-Fix-librepo-version-required-in-CMakeList.txt-1.12.0.patch
  + Patch: 0002-Fix-Fully-set-ssl-in-newHandle-function.patch
  + Patch: 0003-conf-Add-options-for-working-with-certificates-used-.patch
  + Patch: 0004-Apply-proxy-certificate-options.patch
* Sat Feb 13 2021 Neal Gompa <ngompa13@gmail.com>
- Backport another fix for adding controls to installonlypkgs
  + Patch: 0001-context-Fix-dnf_package_is_installonly-RhBug-1928056.patch
* Sat Feb 13 2021 Neal Gompa <ngompa13@gmail.com>
- Add patch to move directory for dnf state data to /usr/lib/sysimage
  + Patch: libdnf-0.58.0-Use-usr-lib-sysimage-for-the-persistent-state-dir.patch
* Fri Feb 12 2021 Neal Gompa <ngompa13@gmail.com>
- Backport fixes to add controls for installonlypkgs and protected_packages
  + Patch: 0001-context-Support-config-file-option-installonlypkgs.patch
  + Patch: 0002-context-Support-config-file-option-protected_package.patch
* Tue Feb  2 2021 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.58.0
  + Option: Add reset() method
  + Add OptionBinds::getOption() method
  + [context] Add dnf_repo_conf_from_gkeyfile() and dnf_repo_conf_reset()
  + [context] Add support for options: minrate, throttle, bandwidth, timeout
  + [context] Remove g_key_file_get_string() from dnf_repo_set_keyfile_data()
  + Allow loading ext metadata even if only cache (solv) is present
  + Add ASAN_OPTIONS for test_libdnf_main
  + [context,API] Functions for accessing main/global configuration options
  + [context,API] Function for adding setopt
  + Add getter for modular obsoletes from ModuleMetadata
  + Add ModulePackage.getStaticContext() and getRequires()
  + Add compatible layer for MdDocuments v2
  + Fix modular queries with the new solver
  + Improve formatting of error string for modules
  + Change mechanism of module conflicts
  + Fix load/update FailSafe
- Drop patch included in this release
  + Patch: 0001-context-Sync-missing-arches-from-DNF.patch
* Mon Jan  4 2021 Neal Gompa <ngompa13@gmail.com>
- Add patch to support armv6hl and RISC-V architectures
  + Patch: 0001-context-Sync-missing-arches-from-DNF.patch
* Sun Dec  6 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.55.2
  + Improve performance of query installed() and available()
  + Swdb: Add a method to get the current transaction
  + [modules] Add special handling for src artifacts (rh#1809314)
  + Better msgs if "basecachedir" or "proxy_password" isn't set (rh#1888946)
  + Add new options module_stream_switch
  + Support allow_vendor_change setting in dnf context API
- Drop patches incorporated into this release
  + Patch: 0001-Support-allow_vendor_change-setting-in-dnf-context-A.patch
  + Patch: 0001-context-dnf_keyring_add_public_keys-not-generate-err.patch
- Use cmake_build and cmake_install macros
* Sun Nov 29 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.55.0
  + Add vendor to dnf API (rh#1876561)
  + Add formatting function for solver error
  + Add error types in ModulePackageContainer
  + Implement module enable for context part
  + Improve string formatting for translation
  + Remove redundant printf and change logging info to notice (rh#1827424)
  + Add allow_vendor_change option (rh#1788371) (rh#1788371)
- Backport patches from upstream
  + Patch: 0001-Support-allow_vendor_change-setting-in-dnf-context-A.patch
  + Patch: 0001-context-dnf_keyring_add_public_keys-not-generate-err.patch
- Add patch to turn off changing vendors by default
  + Patch: libdnf-0.55.0-Switch-allow_vendor_change-off.patch
* Sat Oct 24 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.54.2
  + history: Fix dnf history rollback when a package was removed (rh#1683134)
  + Add support for HY_GT, HY_LT in query nevra_strict
  + Fix parsing empty lines in config files
  + Accept '==' as an operator in reldeps (rh#1847946)
  + Add log file level main config option (rh#1802074)
  + Add protect_running_kernel configuration option (rh#1698145)
  + Context part of libdnf cannot assume zchunk is on (rh#1851841, rh#1779104)
  + Fix memory leak of resultingModuleIndex and handle g_object refs
  + Redirect librepo logs to libdnf logs with different source
  + Add hy_goal_lock
  + Enum/String conversions for Transaction Store/Replay
  + utils: Add a method to decode URLs
  + Unify hawkey.log line format with the rest of the logs
- Drop patches included in this release
  + Patch: 0001-tests-Fix-incorrect-usage-of-the-fail_unless-macro.patch
- Refresh patch for reposdir paths
  + Remove patch: libdnf-0.39.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  + Add patch: libdnf-0.54.2-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Fri Aug 21 2020 Neal Gompa <ngompa13@gmail.com>
- Backport fix from upstream to fix building against check >= 0.15
  + Patch: 0001-tests-Fix-incorrect-usage-of-the-fail_unless-macro.patch
- Clean up spec comments about patches
* Tue Jul  7 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.48.0
  + Add prereq_ignoreinst & regular_requires properties for pkg (rh#1543449)
  + Reset active modules when no module enabled or default (rh#1767351)
  + Add comment option to transaction (rh#1773679)
  + Failing to get module defauls is a recoverable error
  + Baseurl is not exclusive with mirrorlist/metalink (rh#1775184)
  + Add new function to reset all modules in C API (dnf_context_reset_all_modules)
  + [context] Fix to preserve additionalMetadata content (rh#1808677)
  + Fix filtering of DepSolvables with source rpms (rh#1812596)
  + Add setter for running kernel protection setting
  + Handle situation when an unprivileged user cannot create history database (rh#1634385)
  + Add query filter: latest by priority
  + Add DNF_NO_PROTECTED flag to allow empty list of protected packages
  + Remove 'dim' option from terminal colors to make them more readable (rh#1807774, rh#1814563)
  + [context] Error when main config file can't be opened (rh#1794864)
  + [context] Add function function dnf_context_is_set_config_file_path
  + swdb: Catch only SQLite3 exceptions and simplify the messages
  + MergedTransaction list multiple comments (rh#1773679)
  + Modify CMake to pull *.po files from weblate
  + Optimize DependencyContainer creation from an existing queue
  + fix a memory leak in dnf_package_get_requires()
  + Fix memory leaks on g_build_filename()
  + Fix memory leak in dnf_context_setup()
  + Add `hy_goal_favor` and `hy_goal_disfavor`
  + Define a cleanup function for `DnfPackageSet`
  + dnf-repo: fix dnf_repo_get_public_keys double-free
  + Do not cache RPMDB
  + Use single-quotes around string literals used in SQL statements
  + SQLite3: Do not close the database if it wasn't opened (rh#1761976)
  + Don't create a new history DB connection for in-memory DB
  + transaction/Swdb: Use a single logger variable in constructor
  + utils: Add a safe version of pathExists()
  + swdb: Handle the case when pathExists() fails on e.g. permission
  + Repo: prepend "file://" if a local path is used as baseurl
  + Move urlEncode() to utils
  + utils: Add 'exclude' argument to urlEncode()
  + Encode package URL for downloading through librepo (rh#1817130)
  + Replace std::runtime_error with libdnf::RepoError
  + Fixes and error handling improvements of the File class
  + [context] Use ConfigRepo for gpgkey and baseurl (rh#1807864)
  + [context] support "priority" option in .repo config file (rh#1797265)
- Drop obsolete patch: libdnf-0.45.0-handle-all-rpmdb-variants.patch
- Refresh patch for static linking libsolvext
  + Remove patch: libdnf-0.39.1-with-static-libsolvext.patch
  + Add patch: libdnf-0.48.0-with-static-libsolvext.patch
* Mon Mar 23 2020 Neal Gompa <ngompa13@gmail.com>
- Remove unused BR for gobject-introspection
* Sun Mar 22 2020 Neal Gompa <ngompa13@gmail.com>
- Add patch to support monitoring non-bdb rpmdb variants
  + Patch: libdnf-0.45.0-handle-all-rpmdb-variants.patch
* Thu Feb 27 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.45.0
  + Config options: only first empty value clears existing (rh#1788154)
  + Make parsing of reldeps more strict (rh#1788107)
  + [context] Support repositories defined in main configuration file
  + Fix filtering packages by advisory when more versions and arches are available (rh#1770125)
  + Add expanding solvable provides for dependency matching (rh#1534123)
  + DnfRepo: fix module_hotfixes keyfile priority level
  + Add custom exceptions to libdnf interface
  + [conf] Set useful default colors when color is enabled
  + Port to libmodulemd-2 API (rh#1693683)
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.43.1
  + Allow excluding packages with "excludepkgs" and globs
  + Add two new query filters: obsoletes_by_priority, upgrades_by_priority
  + [context] Use installonly_limit from global config (rh#1256108)
  + [context] Add API to get/set "install_weak_deps"
  + [context] Add wildcard support for repo_id in dnf_context_repo_enable/disable (rh#1781420)
  + [context] Adds support for includepkgs in repository configuration.
  + [context] Adds support for excludepkgs, exclude, includepkgs, and disable_excludes in main configuration.
  + [context] Added function dnf_transaction_set_dont_solve_goal
  + [context] Added functions dnf_context_get/set_config_file_path
  + [context] Respect "plugins" global conf value
  + [context] Add API to disable/enable plugins
* Sun Dec  1 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.39.1
  + Skip invalid key files in "/etc/pki/rpm-gpg" with warning (rh#1644040)
  + Enable timestamp preserving for downloaded data (rh#1688537)
  + Set default to skip_if_unavailable=false (rh#1679509)
  + Add configuration option skip_if_unavailable (rh#1689931)
  + Fix 'database is locked' error (rh#1631533)
  + Replace the 'Failed to synchronize cache' message (rh#1712055)
  + Fix 'no such table: main.trans_cmdline' error (rh#1596540)
  + Add support of modular FailSafe (rh#1623128) (temporarily with warnings
    instead of errors when installing modular RPMs without modular metadata)
  + Add support of DNF main config file in context; used by PackageKit and
    microdnf (rh#1689331)
  + Exit gpg-agent after repokey import (rh#1650266)
  + Don't disable nonexistent but required repositories (rh#1689331)
  + Fix toString() to not insert [] (rh#1584442)
  + Ignore trailing blank lines in config (rh#1722493)
  + Fix handling large number of filenames on input (rh#1690915)
  + Detect armv7 with crypto extension only on arm version >= 8
  + A new standardized User-Agent field consisting of the libdnf and OS version
    (including the variant) (rh#1156007)
  + Add basic countme support (rh#1647454)
  + Fix crash in PackageKit (rh#1636803)
  + Do not create @System.solv files (rh#1707995)
  + Set LRO_CACHEDIR so zchunk works again (rh#1739867)
  + Don't reinstall modified packages with the same NEVRA (rh#1644241)
  + Fix bug when moving temporary repository metadata after download (rh#1700341)
  + Improve detection of extras packages by comparing (name, arch) pair
    instead of full NEVRA (RhBuh:1684517)
  + Improve handling multilib packages in the history command (rh#1728637)
  + Repo download: use full error description into the exception text (rh#1741442)
  + Properly close hawkey.log (rh#1594016)
  + Fix dnf updateinfo --update to not list advisories for packages updatable
    only from non-enabled modules
  + Apply modular filtering by package name (rh#1702729)
  + Fully enable the modular fail safe mechanism (rh#1616167)
  + Use more descriptive message when failed to retrieve GPG key (rh#1605117)
  + Add removeMetadataTypeFromDownload function to the API
  + Context part of libdnf can now read vars (urlvars) from dirs and environment
  + Throw exception immediately if file cannot be opened
  + Add test when there is no primary metadata in compatible format (rh#1744960)
  + Don't abort on rpmdb checksum calculation failure
  + Enable module dependency trees when using set_modules_enabled_by_pkgset() (rh#1762314)
  + New method "Query::filterSubject()", replaces Solution::getBestSolution()
  + The Solution class was removed
  + Add query argument into get_best_query and get_best_solution
  + Add module reset function into dnf_context
  + Add method to get all repository metadata locations
  + Catch NoModuleException in case of not existent value was used in persistor (rh#1761773)
  + Handle NoModuleException in dnf_context_reset_modules (rh#1767453)
  + Report reason how package was excluded (rh#1649754)
  + Fix Arm detection improvements (rh#1691430)
  + Set skip_if_unavailable to true for all media repos (rh#1716067)
  + Only the pkg knows whether it is local or remote (rh#1734350, rh#1717865)
  + Don't use repo's packages as path to local pkgs (rh#1734350, rh#1717865)
- Drop patch for temporarily dropping support for module advisories
  * Patch: libdnf-0.31.0-Revert-support-for-Module-advisories.patch
- Refresh patches
  * Remove patch: libdnf-0.28.1-with-static-libsolvext.patch
  * Remove patch: libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  * Add patch: libdnf-0.39.1-with-static-libsolvext.patch
  * Add patch: libdnf-0.39.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Fri May 10 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.33.0
  + Import subkeys when importing GPG keys (gh#projectatomic/rpm-ostree#1094)
  + [module] Fix swig binding for getModuleDependencies() (rh#1704871)
  + [module] Prevent std::string from nullptr (gh#rpm-software-management/libdnf#717)
  + Reintroduce hawkey.Repo as deprecated class
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Add patch for SLE to temporarily drop support for Module advisories
  * Patch: libdnf-0.31.0-Revert-support-for-Module-advisories.patch
* Fri Apr 26 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.31.0
  + Installroot now requires absolute path
  + Support "_none_" value for repo option "proxy" (rh#1680272)
  + Add support for Module advisories
  + Add support for xml:base attribute from primary.xml (rh#1691315)
  + Fix detection of Platform ID for modules (rh#1688462)
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.28.1
  + Enhance modular solver to handle enabled and default module streams differently (rh#1648839)
  + Add support of wild cards for modules (rh#1644588)
  + Exclude module pkgs that have conflict
  + Enhance config parser to preserve order of data, and keep comments and format
  + Improve ARM detection
  + Add support for SHA-384
  + Return empty query if incorrect reldep (rh#1687135)
  + ConfigParser: Improve compatibility with Python ConfigParser and dnf-plugin-spacewalk (rh#1692044)
  + ConfigParser: Unify default set of string represenation of boolean values
  + Fix segfault when interrupting dnf process (rh#1610456)
- Drop backported patches that are part of this release
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patches
  * Remove patch: libdnf-0.24.1-with-static-libsolvext.patch
  * Remove patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
  * Add patch: libdnf-0.28.1-with-static-libsolvext.patch
  * Add patch: libdnf-0.28.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Wed Feb 13 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
- Adjust RPM groups.
* Wed Feb 13 2019 Neal Gompa <ngompa13@gmail.com>
- Fix cmake macro pointer to source tree
* Thu Feb  7 2019 Neal Gompa <ngompa13@gmail.com>
- Switch default reposdir to /etc/dnf/repos.d
  * Add patch: libdnf-0.24.1-Switch-default-reposdir-to-etc-dnf-repos.d.patch
* Tue Feb  5 2019 Neal Gompa <ngompa13@gmail.com>
- Rebase to version 0.24.1
  + Add support for RH/Fedora modules
  + Add plugin support (unstable API)
  + Add zchunk support
  + Migrate from YUMDB to new SWDB
  + Rewrite into C++
- Drop Python 2 bindings
- Backport fixes from upstream eliminate various bugs
  * 0001-Reset-callback-to-NULL-RhBug-1637923.patch
  * 0002-reldep-list-Add-glib-AUTOPTR-cleanup.patch
  * 0003-swdb-Put-Swdb-constructors-together.patch
  * 0004-utils-Drop-empty-else-block.patch
  * 0005-transformer-Fix-minor-docstring-typo.patch
  * 0006-repo-Squash-Wmaybe-uninitialized-warning.patch
  * 0007-transaction-Consistently-use-the-same-swdb-variable.patch
  * 0008-transaction-Minor-syntax-tweak.patch
- Add proposed patches for improving zchunk support
  * 0101-Zchunk-configuration-flags-were-backwards-so-setting.patch
  * 0102-hy_repos-weren-t-being-filled-properly-when-using-zc.patch
- Refresh patch for linking to static libsolvext
  * Remove patch: libdnf-0.9.3-with-static-libsolvext.patch
  * Add patch: libdnf-0.24.1-with-static-libsolvext.patch
- Drop patch merged in upstream libdnf
  * 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Aug 20 2018 Neal Gompa <ngompa13@gmail.com>
- Refresh patch to fix building against static libsolvext
- Switch to full author identities
* Thu Jan  4 2018 Neal Gompa <ngompa13@gmail.com>
- Ensure SUSE kernel packages are recognized properly
  * New patch: 0001-Add-multiversion-kernel-as-a-recognized-installonlyp.patch
* Mon Nov 13 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.1:
  + Make NEVRA parsing stricter
  + Fix segfault with queries if epoch isn't set
  + Improve performance of queries of solvables
* Tue Oct 10 2017 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.11.0:
  + Improves query performance with 'name' and 'arch' filters.
    Also 'nevra' filter will now handle string with or without
    'epoch'.
  + For Python bindings, it renames 'NEVRA._has_just_name()' to
    'NEVRA.has_just_name()' as it's now implemented in the C API.
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Fix building on openSUSE against static libsolvext
  * New patch: libdnf-0.9.3-with-static-libsolvext.patch
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia package
